# -*- coding: utf-8 -*-

"""jcast.__main__: executed when jcast directory is called as script."""

from jcast.main import main

main()